@@ -8,6 +8,7 @@ from sql import Table, Literal, Null
 from sql.functions import Overlay, Position
 from sql.aggregate import Count
 from sql.operators import Concat
+from sql.conditionals import Case
 
 from trytond.model import Workflow, ModelView, ModelSQL, fields
 from trytond.modules.company import CompanyReport
@@ -150,8 +151,7 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
     shipment_returns = fields.Function(
         fields.One2Many('stock.shipment.in.return', None, 'Shipment Returns'),
         'get_shipment_returns')
-    moves = fields.Function(fields.One2Many('stock.move', None, 'Moves'),
-        'get_moves')
+    moves = fields.One2Many('stock.move', 'purchase', 'Moves', readonly=True)
 
     @classmethod
     def __setup__(cls):
@@ -505,7 +505,7 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
 
     @classmethod
     def search_invoices(cls, name, clause):
-        return [('lines.invoice_lines.invoice.id',) + tuple(clause[1:])]
+        return [('lines.invoice_lines.invoice',) + tuple(clause[1:])]
 
     def get_invoice_state(self):
         '''
@@ -548,9 +548,6 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
     get_shipments = get_shipments_returns('stock.shipment.in')
     get_shipment_returns = get_shipments_returns('stock.shipment.in.return')
 
-    def get_moves(self, name):
-        return [m.id for l in self.lines for m in l.moves]
-
     def get_shipment_state(self):
         '''
         Return the shipment state for the purchase.
@@ -596,7 +593,7 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
 
     @classmethod
     def view_attributes(cls):
-        return [('//field[@name="comment"]', 'spell', Eval('party_lang'))]
+        return [('/form//field[@name="comment"]', 'spell', Eval('party_lang'))]
 
     @classmethod
     def copy(cls, purchases, default=None):
@@ -607,6 +604,7 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
         default['reference'] = None
         default['invoice_state'] = 'none'
         default['invoices_ignored'] = None
+        default['moves'] = None
         default['shipment_state'] = 'none'
         default.setdefault('purchase_date', None)
         return super(Purchase, cls).copy(purchases, default=default)
@@ -711,7 +709,9 @@ class Purchase(Workflow, ModelSQL, ModelView, TaxableMixin):
             return
 
         invoice = self._get_invoice_purchase(invoice_type)
-        invoice.lines = list(chain.from_iterable(invoice_lines.itervalues()))
+        invoice.lines = list(chain.from_iterable(
+                invoice_lines[l.id] for l in self.lines
+                if l.id in invoice_lines))
         invoice.save()
 
         Invoice.update_taxes([invoice])
@@ -949,11 +949,9 @@ class PurchaseLine(ModelSQL, ModelView):
             'To Location'), 'get_to_location')
     delivery_date = fields.Function(fields.Date('Delivery Date',
             states={
-                'invisible': ((Eval('type') != 'line')
-                    | (If(Bool(Eval('quantity')), Eval('quantity', 0), 0)
-                        <= 0)),
+                'invisible': Eval('type') != 'line',
                 },
-            depends=['type', 'quantity']),
+            depends=['type']),
         'on_change_with_delivery_date')
 
     @classmethod
@@ -990,7 +988,7 @@ class PurchaseLine(ModelSQL, ModelView):
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == Null, table.sequence]
+        return [Case((table.sequence == Null, 0), else_=1), table.sequence]
 
     @staticmethod
     def default_type():
@@ -1176,9 +1174,12 @@ class PurchaseLine(ModelSQL, ModelView):
         else:
             return self.purchase.party.supplier_location.id
 
-    @fields.depends('product', 'quantity',
+    @fields.depends('product', 'quantity', 'moves',
         '_parent_purchase.purchase_date', '_parent_purchase.party')
     def on_change_with_delivery_date(self, name=None):
+        if self.moves:
+            return min(m.effective_date if m.effective_date else m.planned_date
+                for m in self.moves)
         if (self.product
                 and self.quantity > 0
                 and self.purchase and self.purchase.party
@@ -1282,7 +1283,8 @@ class PurchaseLine(ModelSQL, ModelView):
 
     @classmethod
     def view_attributes(cls):
-        return [('//field[@name="note"]|//field[@name="description"]',
+        return [
+            ('/form//field[@name="note"]|/form//field[@name="description"]',
                 'spell', Eval('_parent_purchase', {}).get('party_lang'))]
 
     @classmethod
@@ -1407,13 +1409,7 @@ class OpenSupplier(Wizard):
         supplier_ids = [line[0] for line in cursor.fetchall()]
         action['pyson_domain'] = PYSONEncoder().encode(
             [('id', 'in', supplier_ids)])
-
-        model_data, = ModelData.search([
-                ('fs_id', '=', 'act_open_supplier'),
-                ('module', '=', 'purchase'),
-                ], limit=1)
-        wizard = Wizard(model_data.db_id)
-
+        wizard = Wizard(ModelData.get_id('purchase', 'act_open_supplier'))
         action['name'] = wizard.name
         return action, {}
 
