@@ -1,29 +1,19 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 import unittest
 import doctest
 from decimal import Decimal
 
 import trytond.tests.test_tryton
-from trytond.tests.test_tryton import test_view, test_depends
+from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import POOL, DB_NAME, USER, CONTEXT
 from trytond.tests.test_tryton import doctest_setup, doctest_teardown
 from trytond.transaction import Transaction
 
 
-class PurchaseTestCase(unittest.TestCase):
+class PurchaseTestCase(ModuleTestCase):
     'Test Purchase module'
-
-    def setUp(self):
-        trytond.tests.test_tryton.install_module('purchase')
-
-    def test0005views(self):
-        'Test views'
-        test_view('purchase')
-
-    def test0006depends(self):
-        'Test depends'
-        test_depends()
+    module = 'purchase'
 
     def test_purchase_price(self):
         'Test purchase price'
@@ -116,7 +106,7 @@ def suite():
     suite = trytond.tests.test_tryton.suite()
     from trytond.modules.company.tests import test_company
     for test in test_company.suite():
-        if test not in suite:
+        if test not in suite and not isinstance(test, doctest.DocTestCase):
             suite.addTest(test)
     from trytond.modules.account.tests import test_account
     for test in test_account.suite():
